

.. _sphx_glr_auto_examples_monitoring_msg.py:


==========
MSG reader
==========

This application demonstrates how to access MSGs from Ligier.




.. code-block:: python

    from __future__ import absolute_import, print_function, division

    import io
    import km3pipe as kp

    __author__ = "Tamas Gal"
    __email__ = "tgal@km3net.de"


    def print_msg(blob):
        data = io.BytesIO(blob['CHData'])
        print(data)
        return blob


    pipe = kp.Pipeline()
    pipe.attach(kp.io.CHPump, host='localhost', tags='MSG')
    pipe.attach(print_msg)
    pipe.drain()

**Total running time of the script:** ( 0 minutes  0.000 seconds)



.. only :: html

 .. container:: sphx-glr-footer


  .. container:: sphx-glr-download

     :download:`Download Python source code: msg.py <msg.py>`



  .. container:: sphx-glr-download

     :download:`Download Jupyter notebook: msg.ipynb <msg.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
